/**
  ******************************************************************************
  * File Name          : main.c
  * Description        : Main program body
  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "hw_config.h"
#include "stm32l152c_discovery_glass_lcd.h"
#include "tsl_user.h"

/* Private defines -----------------------------------------------------------*/
#define DATA_EEPROM_START_ADDR     0x08080000
#define MAX_SPEED 5
#define PAUSE 2                 // 2 sec
#define START_ENABLE 5          //     
#define DAK_A0 16               //     
#define DAK_Scale 22            //     
#define DAK_ADC_A0 352          //     
#define DAK_ADC_A90 2332        //     

/* Private macros ------------------------------------------------------------*/
#define LED_GREEN_ON {HAL_GPIO_WritePin(LD3_GPIO_Port, LD3_Pin, GPIO_PIN_SET);}
#define LED_GREEN_OFF {HAL_GPIO_WritePin(LD3_GPIO_Port, LD3_Pin, GPIO_PIN_RESET);}

/* Private variables ---------------------------------------------------------*/
extern ADC_HandleTypeDef hadc;
extern DAC_HandleTypeDef hdac;
extern uint32_t process_sensor;
uint32_t process_sensor_back, Step_DRV_Enable=0, Step_Dir=0, Start_Touch=0, Start_Mode2=0, TSL_asq_count, Steps_count;
uint32_t flag_button=0, release_button=0, Mode=0, flag_menu=0, flag_pause=0, flag_delay=0;
unsigned char Slider_Position[7];
extern uint8_t LCDBar;
uint16_t ADC_Result, back_ADC_Result, ADC_Data, ADC_A0, ADC_A90; //     ADC
unsigned char strDisp[6]; //     
uint32_t Sys_sec, Sys_ms, Back_sec, Back_ms, Back_ms_for_pause, Back_ms_for_delay;
uint8_t start_enable, flag_EEPROM, Speed, Pause, DRV_current, A_0, A_140, Scale, A_Min, A_Max; 
uint32_t i;
uint16_t adc_res[8];
float Pause_progress;

/* Private function prototypes -----------------------------------------------*/
//extern HAL_StatusTypeDef FLASH_DATAEEPROM_ProgramByte(uint32_t Address, uint8_t Data);
void ADC_Conv_Disp(void);
void ADC_Conv(void);
void Sort_tab(uint16_t tab[], uint8_t lenght);
void Mode0(void);
void Mode1(void);
void Calibr(void);
extern void Menu(void);
void ProcessSensors(void);
void EE_Save(uint32_t Address, uint8_t Data);
void convert_into_char(uint16_t number, unsigned char *p_tab);

int main(void)
{
	tsl_user_status_t tsl_status;

  /* MCU Configuration----------------------------------------------------------*/
  /* Reset of all peripherals, Initializes the Flash interface and the Systick. */
  HAL_Init();
  /* Configure the system clock */
  SystemClock_Config();
  /* Initialize all configured peripherals */
  MX_GPIO_Init();
  MX_ADC_Init();
  MX_TS_Init();
  MX_TIM6_Init();
  MX_DAC_Init();
  tsl_user_Init();
  /* LCD GLASS Initialization */
  BSP_LCD_GLASS_Init();
	
	/* USER CODE BEGIN 2 */
  Sys_ms = Sys_sec = Back_sec = 0;
  flag_button=0;
  Mode=0;
  flag_menu=0;
  flag_pause=0;
  flag_delay=0;
  start_enable=0;
  if (*(__IO uint8_t*)(DATA_EEPROM_START_ADDR) == 222) //   EEPROM 
  {
    Pause=*(__IO uint8_t*)(DATA_EEPROM_START_ADDR+1);
    Speed=*(__IO uint8_t*)(DATA_EEPROM_START_ADDR+2);
    Scale=*(__IO uint8_t*)(DATA_EEPROM_START_ADDR+3);
    A_0 = *(__IO uint8_t*)(DATA_EEPROM_START_ADDR+4);
		DRV_current = *(__IO uint8_t*)(DATA_EEPROM_START_ADDR+5);
  }
  else
  {
    Pause=PAUSE;
    Speed=MAX_SPEED;
		DRV_current = 2;
    A_0 = DAK_A0; //     
    Scale = DAK_Scale; //     
  }
  A_140 = A_0+150;
  A_Min = A_0-5;
  A_Max = A_140;
	HAL_DAC_Start(&hdac, DAC_CHANNEL_1);
	HAL_DAC_SetValue(&hdac, DAC_CHANNEL_1, DAC_ALIGN_12B_R,(uint32_t)(1023 + DRV_current * 341));
	
//============================================================================
// Main loop
//============================================================================
  while (1)
  {
  /* USER CODE BEGIN 5 */
  /* Infinite loop */
    if ((Sys_sec - Back_sec) < 2) Step_DRV_Enable = 0; //  2 .   -  TSL .
    ADC_Conv_Disp();

    if (process_sensor_back != process_sensor) //     
      if (!process_sensor) //    , ..  
      {
      Start_Touch=1; //    
      TSL_asq_count=5; // -    TSL    
      } 
    process_sensor_back = process_sensor; //    
    // Execute STMTouch Driver state machine
		tsl_status = tsl_user_Exec();
		if ((tsl_status != TSL_USER_STATUS_BUSY) && process_sensor)
		{
			ProcessSensors();
		}
    else
    {  // Execute other tasks...
			LCDBar = 0;
      if (Mode == 2) 
        Mode1();
      else 
        Step_DRV_Enable = 0; //         
      
      //=====================================================================================
      //  :
      //=====================================================================================
      if ((B1_GPIO_Port->IDR & B1_Pin)) //   
      {
        flag_button=1;  //   
        HAL_Delay(10);      // 
        LED_GREEN_ON;
        if ((Sys_ms - Back_ms) >= 2000) // 2 sec. Sys_ms   ms
          Menu();       //   2 . -   
      }
      else      //       :
      {
        Back_ms=Sys_ms; //   Back_ms    
      }
      if ((flag_button==1)&&!(B1_GPIO_Port->IDR & B1_Pin)) //   
      {
        LED_GREEN_OFF;
        flag_button=0;  //    
        if (Mode == 2) 
          Mode = 0;
        else 
        {
          Mode++;
          flag_delay=0; //    
          if (Mode == 2) Start_Mode2=1; //    2 -     2.
        }
      }
      //==========================================================
      //   
      //==========================================================
    }
    //    
    if (Steps_count >= 2*277) // 277    .   TIM6_IRQHandler.
    {
      Steps_count = 0; //    2    
      back_ADC_Result = ADC_Result; //       back_ADC_Result
    }
	}
}

/***************************************/
void ProcessSensors(void)
{
  if (!process_sensor)  return;
	LCDBar = 0;
  if (Mode>=1)
  {
    Mode1();
  } 
  else
  {
    Mode0();
  }
}

/******************************************************/
void Mode1()
{
  if (Start_Touch && (Mode == 2) && process_sensor) //    2
  {
    Step_DRV_Enable ^= 1;   // /    
    start_enable = START_ENABLE; //    
    Start_Touch=0; //     
  }
  else if (Start_Touch  && process_sensor) //    1
  {
    Step_DRV_Enable = 1;    //     
    start_enable = START_ENABLE; //    
    Start_Touch=0; //     
  }
  else if (flag_pause) //        
  {
    Step_DRV_Enable = 0; //  
    if (Pause != 0) //     0
    {
      Pause_progress = (float)(Sys_ms - Back_ms_for_pause)/(Pause*2000); //        
      //           4-  
      if (Pause_progress <= 0.25)	LCDBar = 4; 
      if (Pause_progress <= 0.5)	LCDBar = 3;
      if (Pause_progress <= 0.75)	LCDBar = 2;
      if (Pause_progress <= 0.95)	LCDBar = 1;
    }
    else
      Pause_progress = 1; //    0,     .
    //  
    strDisp[2]=' ';
    strDisp[3]=' ';
    strDisp[4]=' ';
    strDisp[5]=' ';
    BSP_LCD_GLASS_WriteChar(strDisp + 2, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_3);
    BSP_LCD_GLASS_WriteChar(strDisp + 3, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_4);
    BSP_LCD_GLASS_WriteChar(strDisp + 4, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_5);
    BSP_LCD_GLASS_WriteChar(strDisp + 5, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_6); 
    
    if (Pause_progress >= 1) //   :
    {
      start_enable = START_ENABLE; //    
      flag_pause=0; //   
      flag_delay=1; //     
      Back_ms_for_delay = Sys_ms; //     
    }
  }
  else if (flag_delay) //      :
  {
    Step_DRV_Enable = 1; //   
    if ((Sys_ms - Back_ms_for_delay) >= (Speed * 200)) //     (    )
    {
      flag_delay=0; //    
    }
  }
  else if (Step_DRV_Enable) //    :
  {
    if (Step_Dir == 1) //     :
    {
      if ((ADC_Data >= A_Max)) //     
      {
        Step_Dir=0; //    -   
        Back_ms_for_pause = Sys_ms; //     
        flag_pause=1; //   
        Step_DRV_Enable = 0; //     
      }
      else if ((Steps_count/50)>(ADC_Result - back_ADC_Result)) //   -        
      {
        start_enable = START_ENABLE; //    , ..  "",     .
      }
    }
    else        //     :
    {
      if ((ADC_Data <= A_Min))  //   
      {
        Step_Dir=1; //   -   
        Back_ms_for_pause = Sys_ms;//     
        flag_pause=1; //   
        Step_DRV_Enable = 0; //     
      }
      else if ((Steps_count/50)>(back_ADC_Result - ADC_Result)) //   -        
      {
        start_enable = START_ENABLE; //    , ..  "",     .
      }
    }
  }
  //===========================================================================
  //   /  /     
  //===========================================================================
  if (Step_Dir == 1)
  {
    if (ADC_Data > A_Max+2) //   
      Step_DRV_Enable = 0;  //         
    else if (ADC_Data >= (A_Max-5)) //      5 :
    {
      TIM6->ARR = 100 - (A_Max - ADC_Data)*5; //           
    }
    else if (Step_DRV_Enable)
    {
      TIM6->ARR = Speed + start_enable; //   TIM6      
      if (start_enable > 0) //   :
        start_enable--; //         0
    }
  }
  else
  {
    if (ADC_Data < A_Min) //   
      Step_DRV_Enable = 0;      //GPIOC->BSRRH = GPIO_Pin_12; //         
    else if (ADC_Data <= (5+A_Min)) //      5 
    {
      TIM6->ARR = 100 - (ADC_Data - A_Min)*5; //           
    }
    else if (Step_DRV_Enable)
    {
      TIM6->ARR = Speed + start_enable;
      if (start_enable > 0)
        start_enable--;
    }
  }
}

/********************************************************************/
void Mode0()
{
  if (Start_Touch) //   :
  { 
    if (TSL_asq_count == 0) //  
    {
      if (MyLinRots[0].p_Data->Position >= 100)
      {
        Step_Dir=0; //   -   
        Step_DRV_Enable = 1; //      
      }
      if (MyLinRots[0].p_Data->Position <= 20)
      {
        Step_Dir=1; //   -   
        Step_DRV_Enable = 1; //      
      }
      Start_Touch=0;
    }
    else
    {
      TSL_asq_count--;
			return;
    }
  }
  if (Step_Dir == 1)
  {
    if ((ADC_Data >= A_140)) Step_DRV_Enable = 0; //         
    else if (ADC_Data >= (A_140-5))
    {
      TIM6->ARR = 100 - (A_Max - ADC_Data)*5; 
    }
    else
    {
      TIM6->ARR = 100 - 0.76*(MyLinRots[0].p_Data->Position);
    }
    A_Max=ADC_Data;
    if (MyLinRots[0].p_Data->Position >= 2)    LCDBar = 1;
    if (MyLinRots[0].p_Data->Position >= 32)   LCDBar = 2;
    if (MyLinRots[0].p_Data->Position >= 64)   LCDBar = 3;
    if (MyLinRots[0].p_Data->Position >= 96)   LCDBar = 4;
  }
  else
  {
    if ((ADC_Data <= (A_0-5))) Step_DRV_Enable = 0; //         
    else if (ADC_Data <= (5+A_0))
    {
      TIM6->ARR = 100 - (ADC_Data - A_Min)*5;
    }
    else
    {
      TIM6->ARR = 100 - 0.76*(127 - MyLinRots[0].p_Data->Position);
    }
    A_Min=ADC_Data;
    if (MyLinRots[0].p_Data->Position <= 120)  LCDBar = 1;
    if (MyLinRots[0].p_Data->Position <= 96)   LCDBar = 2;
    if (MyLinRots[0].p_Data->Position <= 64)   LCDBar = 3;
    if (MyLinRots[0].p_Data->Position <= 32)   LCDBar = 4;
  }
}

/**************       LCD **********************************/
void ADC_Conv_Disp() 
{
  ADC_Conv();
  ADC_Result = (4096-ADC_Result); //  .. .      
  ADC_Data = ADC_Result/Scale; //.
/*   ADC   .
       1..4*/
  convert_into_char(ADC_Data, strDisp); 
  strDisp[0] = Mode+0x30; //  -  
  strDisp[1] = ' '; //   .
  strDisp[5] = ''; //      
	BSP_LCD_GLASS_WriteChar(strDisp + 0, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_1);
	BSP_LCD_GLASS_WriteChar(strDisp + 1, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_2);
	BSP_LCD_GLASS_WriteChar(strDisp + 2, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_3);
	BSP_LCD_GLASS_WriteChar(strDisp + 3, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_4);
	BSP_LCD_GLASS_WriteChar(strDisp + 4, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_5);
	BSP_LCD_GLASS_WriteChar(strDisp + 5, POINT_OFF, DOUBLEPOINT_OFF, LCD_DIGIT_POSITION_6);
}

/******************************************************/
void ADC_Conv()
{
  for (i=0; i<8; i++) //  8 
  {
    HAL_ADC_Start(&hadc); // 
    HAL_ADC_PollForConversion(&hadc,5); //  ADC
    adc_res[i] = HAL_ADC_GetValue(&hadc); //  
  }
	//      AN4073:
  Sort_tab(adc_res,8); //      ,
  ADC_Result=0; //  2   2   ,
  for (i=2; i<6; i++) ADC_Result+=adc_res[i]; //  4     3  6 
  ADC_Result/=4; // 
}

/*************   *** from  AN4073 *****************/
void Sort_tab(uint16_t tab[], uint8_t lenght)
{
 uint8_t l=0, exchange =1;
 uint16_t tmp=0;

 /* Sort tab */
 while(exchange==1)
 {
   exchange=0;
   for(l=0; l<lenght-1; l++)
   {
     if( tab[l] > tab[l+1] )
     {
       tmp = tab[l];
       tab[l] = tab[l+1];
       tab[l+1] = tmp;
       exchange=1;
     }
   }
 } 
}

/**********      ADC    ***/
void convert_into_char(uint16_t number, unsigned char *p_tab)
{
  uint16_t units=0, tens=0, hundreds=0, thousands=0, misc=0;
  int16_t snumber;
  
  snumber = number-A_0;
  if (snumber < 0)
    number = -snumber;
  else
    number = snumber;
  units = (((number%10000)%1000)%100)%10;
  tens = ((((number-units)/10)%1000)%100)%10;
  hundreds = (((number-tens-units)/100))%100%10;
  thousands = ((number-hundreds-tens-units)/1000)%10;
  misc = ((number-thousands-hundreds-tens-units)/10000);
  
  *(p_tab+4) = units + 0x30;
  if ((tens==0)&&(hundreds==0))
    if (snumber < 0)
      *(p_tab+3)='-';
    else
      *(p_tab+3)=' ';
  else 
    *(p_tab+3) = tens + 0x30;
  if (hundreds==0) 
    *(p_tab+2)=' '; 
  else 
    *(p_tab+2)= hundreds + 0x30;
  *(p_tab+1) = thousands + 0x30;
  *(p_tab) = misc + 0x30;
}

/*******************************************/
void EE_Save(uint32_t Address, uint8_t Data)
{
	HAL_FLASHEx_DATAEEPROM_Unlock();  /* Unlock the FLASH PECR register and Data EEPROM memory */
	HAL_FLASHEx_DATAEEPROM_Program(TYPEPROGRAMDATA_BYTE, Address, Data);
  HAL_FLASHEx_DATAEEPROM_Lock();
}

#ifdef USE_FULL_ASSERT

/**
   * @brief Reports the name of the source file and the source line number
   * where the assert_param error has occurred.
   * @param file: pointer to the source file name
   * @param line: assert_param error line source number
   * @retval None
   */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* USER CODE BEGIN 6 */
  /* User can add his own implementation to report the file name and line number,
    ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */
  /* USER CODE END 6 */

}

#endif

/**
  * @}
  */ 

/**
  * @}
*/ 

/************************ (C) COPYRIGHT STMicroelectronics *****END OF FILE****/
